@@ -1,12 +1,10 @@
-use 5.006;
-use strict;
-use warnings;
+use 5.006; use strict; use warnings;
 
 package Plack::Middleware::Precompressed;
-$Plack::Middleware::Precompressed::VERSION = '1.103';
-# ABSTRACT: serve pre-gzipped content to compression-enabled clients
 
-use parent 'Plack::Middleware';
+our $VERSION = '1.104';
+
+BEGIN { require Plack::Middleware; our @ISA = 'Plack::Middleware' }
 
 use Plack::Util::Accessor qw( match rules env_keys );
 use Plack::MIME ();
@@ -57,11 +55,11 @@ sub call {
 		my $res = shift;
 		$is_fail = $res->[0] != 200;
 		return if $is_fail;
-		Plack::Util::header_push( $res->[1], 'Vary', 'Accept-Encoding' );
+		push @{ $res->[1] }, 'Vary', 'Accept-Encoding';
 		if ( $encoding ) {
 			my $mime = Plack::MIME->mime_type( $path );
 			Plack::Util::header_set( $res->[1], 'Content-Type', $mime ) if $mime;
-			Plack::Util::header_push( $res->[1], 'Content-Encoding', $encoding );
+			push @{ $res->[1] }, 'Content-Encoding', $encoding;
 		}
 		return;
 	} );
@@ -81,10 +79,6 @@ __END__
 
 Plack::Middleware::Precompressed - serve pre-gzipped content to compression-enabled clients
 
-=head1 VERSION
-
-version 1.103
-
 =head1 SYNOPSIS
 
  use Plack::Builder;
@@ -172,7 +166,7 @@ Aristotle Pagaltzis <pagaltzis@gmx.de>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Aristotle Pagaltzis.
+This software is copyright (c) 2022 by Aristotle Pagaltzis.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
